@@ -18,7 +18,6 @@ pub struct Price {
     pub value: f64,
 }
 
-#[cfg(any(feature = "sqlite", feature = "postgres", feature = "mysql",))]
 impl<'q> Price {
     // test schemas on compile time
     #[allow(dead_code)]
@@ -47,6 +46,7 @@ impl<'q> Price {
         )
     }
 
+    #[cfg(any(feature = "sqlite", feature = "postgres", feature = "mysql",))]
     pub(crate) fn query<DB, O>(
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
     where
@@ -70,6 +70,7 @@ impl<'q> Price {
         )
     }
 
+    #[cfg(any(feature = "sqlite", feature = "mysql",))]
     pub(crate) fn query_by_guid_question_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -97,6 +98,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "postgres"))]
     pub(crate) fn query_by_guid_money_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -124,6 +126,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "sqlite", feature = "mysql",))]
     pub(crate) fn query_by_commodity_guid_question_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -151,6 +154,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "postgres"))]
     pub(crate) fn query_by_commodity_guid_money_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -178,6 +182,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "sqlite", feature = "mysql",))]
     pub(crate) fn query_by_currency_guid_question_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -205,6 +210,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "postgres"))]
     pub(crate) fn query_by_currency_guid_money_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -232,6 +238,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "sqlite", feature = "mysql",))]
     pub(crate) fn query_by_commodity_or_currency_guid_question_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -261,6 +268,7 @@ impl<'q> Price {
         .bind(guid)
     }
 
+    #[cfg(any(feature = "postgres"))]
     pub(crate) fn query_by_commodity_or_currency_guid_money_mark<DB, O, T>(
         guid: T,
     ) -> sqlx::query::QueryAs<'q, DB, O, <DB as sqlx::database::HasArguments<'q>>::Arguments>
@@ -296,6 +304,7 @@ impl<'q> Price {
 }
 
 #[cfg(test)]
+#[cfg(any(feature = "sqlite", feature = "postgres", feature = "mysql"))]
 mod tests {
     use super::*;
     use futures::executor::block_on;
