@@ -1,27 +1,26 @@
 use rucash::mysql::Account;
-use rucash::Book;
+use rucash::prelude::*;
+use rucash::MySQLBook;
 
 const URI: &str = "mysql://user:secret@localhost/complex_sample.gnucash";
 
-type DB = sqlx::MySql;
-type RAW = rucash::Ignore;
 mod book {
     use super::*;
 
     #[test]
     fn new() {
-        Book::<DB, RAW>::new(URI).unwrap();
+        MySQLBook::new(URI).unwrap();
     }
 
     #[test]
     #[should_panic]
     fn new_fail() {
-        Book::<DB, RAW>::new("mysql://user@localhost").unwrap();
+        MySQLBook::new("mysql://user@localhost").unwrap();
     }
 
     #[test]
     fn accounts_filter() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let accounts: Vec<Account> = book
             .accounts()
             .unwrap()
@@ -33,49 +32,49 @@ mod book {
 
     #[test]
     fn accounts_by_name() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let accounts = book.accounts_contains_name("aS").unwrap();
         assert_eq!(accounts.len(), 3);
     }
 
     #[test]
     fn account_by_name() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("aS").unwrap().unwrap();
         assert_eq!(account.name, "Asset");
     }
 
     #[test]
     fn splits() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let splits = book.splits().unwrap();
         assert_eq!(splits.len(), 25);
     }
 
     #[test]
     fn transactions() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let transactions = book.transactions().unwrap();
         assert_eq!(transactions.len(), 11);
     }
 
     #[test]
     fn prices() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let prices = book.prices().unwrap();
         assert_eq!(prices.len(), 5);
     }
 
     #[test]
     fn commodities() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodities = book.commodities().unwrap();
         assert_eq!(commodities.len(), 5);
     }
 
     #[test]
     fn currencies() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let currencies = book.currencies().unwrap();
         assert_eq!(currencies.len(), 4);
     }
@@ -84,7 +83,7 @@ mod account {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -114,7 +113,7 @@ mod account {
 
     #[test]
     fn balance() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -127,7 +126,7 @@ mod account {
     }
     #[test]
     fn balance_diff_currency() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book
             .accounts()
             .unwrap()
@@ -140,7 +139,7 @@ mod account {
     }
     #[test]
     fn splits() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let splits = account.splits().unwrap();
         assert_eq!(splits.len(), 3);
@@ -148,7 +147,7 @@ mod account {
 
     #[test]
     fn parent() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let parent = account.parent().unwrap();
         assert_eq!(parent.name, "Current");
@@ -156,7 +155,7 @@ mod account {
 
     #[test]
     fn no_parent() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("Root Account").unwrap().unwrap();
         let parent = account.parent();
         assert!(parent.is_none());
@@ -164,7 +163,7 @@ mod account {
 
     #[test]
     fn children() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("Current").unwrap().unwrap();
         let children = account.children().unwrap();
         assert_eq!(children.len(), 3);
@@ -172,7 +171,7 @@ mod account {
 
     #[test]
     fn commodity() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let account = book.account_by_name("Cash").unwrap().unwrap();
         let commodity = account.commodity().unwrap();
         assert_eq!(commodity.mnemonic, "EUR");
@@ -183,7 +182,7 @@ mod split {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -217,7 +216,7 @@ mod split {
     }
     #[test]
     fn transaction() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -231,7 +230,7 @@ mod split {
 
     #[test]
     fn account() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let split = book
             .splits()
             .unwrap()
@@ -248,7 +247,7 @@ mod transaction {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -286,7 +285,7 @@ mod transaction {
 
     #[test]
     fn currency() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -300,7 +299,7 @@ mod transaction {
 
     #[test]
     fn splits() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let transaction = book
             .transactions()
             .unwrap()
@@ -317,7 +316,7 @@ mod price {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -342,7 +341,7 @@ mod price {
 
     #[test]
     fn commodity() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -356,7 +355,7 @@ mod price {
 
     #[test]
     fn currency() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let price = book
             .prices()
             .unwrap()
@@ -373,7 +372,7 @@ mod commodity {
     use super::*;
     #[test]
     fn property() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -395,7 +394,7 @@ mod commodity {
 
     #[test]
     fn accounts() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -409,7 +408,7 @@ mod commodity {
 
     #[test]
     fn transactions() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -423,7 +422,7 @@ mod commodity {
 
     #[test]
     fn as_commodity_prices() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -437,7 +436,7 @@ mod commodity {
 
     #[test]
     fn as_currency_prices() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -451,7 +450,7 @@ mod commodity {
 
     #[test]
     fn as_commodity_or_currency_prices() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -466,7 +465,7 @@ mod commodity {
     #[test]
     fn rate_direct() {
         // ADF => AED
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -488,7 +487,7 @@ mod commodity {
         assert_eq!(rate, 1.0 / 1.5);
 
         // AED => EUR
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
@@ -512,7 +511,7 @@ mod commodity {
 
     #[test]
     fn rate_indirect() {
-        let book = Book::<DB, RAW>::new(URI).unwrap();
+        let book = MySQLBook::new(URI).unwrap();
         let commodity = book
             .commodities()
             .unwrap()
